<?php
/**
 *
 * @category        helperscript
 * @package         realtime image resizer
 * @author          Ruud Esinga
 * @license         http://www.gnu.org/licenses/gpl.html
 * @platform        WebsiteBaker 2.8.2
 * @requirements    PHP 5.2.2 and higher
 * @version         0.1
 * @lastmodified    Date: 2012-04-06
 *
 */

include ( '../config.php');
include ( '../framework/functions.php');
$cachedir = WB_PATH.MEDIA_DIRECTORY.'/cached_images/';
make_dir($cachedir);

$max_width = isset($_GET["w"])?intval($_GET["w"]):1024;
$max_height = isset($_GET["h"])?intval($_GET["h"]):1024;
$image = $_GET["i"];
$image = WB_PATH.MEDIA_DIRECTORY.'/'.str_replace(WB_URL.MEDIA_DIRECTORY,'',$image);

if (strrchr($image, '/')) {
	$filename = substr(strrchr($image, '/'), 1); // remove folder references
} else {
	$filename = $image;
}
$size = @getimagesize($image);
if(!$size) notfound();
$width = $size[0];
$height = $size[1];
$imageModified = @filemtime($image);
//Original size? output the image directly
if ($width == $max_width) {
	header("Content-type: image/jpeg");
	cacheHeaders($imageModified);
	readfile($image);
	exit;
}

$x_ratio = $max_width / $width;
$y_ratio = $max_height / $height;
if (($width <= $max_width) && ($height <= $max_height) ) {
	$tn_width = $width;
	$tn_height = $height;
} else if (($x_ratio * $height) < $max_height) {
	$tn_height = ceil($x_ratio * $height);
	$tn_width = $max_width;
} else {
	$tn_width = ceil($y_ratio * $width);
	$tn_height = $max_height;
}
$resized = $cachedir.$tn_width.'x'.$tn_height.'-'.str_replace('/','_',str_replace(WB_PATH,'',$image));
$thumbModified = @filemtime($resized);
// if thumbnail is newer than image then output cached thumbnail and exit
if($imageModified<$thumbModified) {
	header("Content-type: image/jpeg");
	cacheHeaders($thumbModified);
	readfile($resized);
	exit;
}
$ext = strtolower(substr(strrchr($image, '.'), 1)); // get the file extension
switch ($ext) { 
	case 'jpg':     // jpg
		$src = imagecreatefromjpeg($image);
		break;
	case 'png':     // png
		$src = imagecreatefrompng($image);
		break;
	case 'gif':     // gif
		$src = imagecreatefromgif($image);
		break;
	default:
		die();
}
$dst = imagecreatetruecolor($tn_width,$tn_height);
imageantialias ($dst, true);
imagecopyresampled ($dst, $src, 0, 0, 0, 0, $tn_width, $tn_height, $width, $height);
if (function_exists("imageconvolution")) { //sharpen - >= PHP5.1
	$matrix = array( array( -1, -1, -1 ), array( -1, 32, -1 ), array( -1, -1, -1 ) );
	$divisor = 24;
	$offset = 0;
	imageconvolution($dst, $matrix, $divisor, $offset);
}
header("Content-type: image/jpeg");
imagejpeg($dst, null, -1);
imagejpeg($dst, $resized, -1);
imagedestroy($src);
imagedestroy($dst);


function cacheHeaders($lastModifiedDate) {
	if ($lastModifiedDate) {
		if (isset($_SERVER['HTTP_IF_MODIFIED_SINCE']) && strtotime($_SERVER['HTTP_IF_MODIFIED_SINCE']) >= $lastModifiedDate) {
			if (php_sapi_name()=='CGI') {
				Header("Status: 304 Not Modified");
			} else {
				Header("HTTP/1.0 304 Not Modified");
			}
			exit;
		} else {
			$gmtDate = gmdate("D, d M Y H:i:s \G\M\T",$lastModifiedDate);
			header('Last-Modified: '.$gmtDate);
		}
	}
}
function notfound() {
	header($_SERVER["SERVER_PROTOCOL"]." 404 Not Found"); 
	exit;
}
?>